@@ -71,7 +71,7 @@ AbstractAnnotationItem *AnnotationItemFactory::create(const QPointF &initPositio
 	auto properties = mPropertiesFactory->create(toolType);
 	auto newItem = createItem(initPosition, toolType, properties);
 
-	setZValue(newItem);
+	initItem(newItem);
 
 	return newItem;
 }
@@ -81,7 +81,7 @@ AbstractAnnotationItem *AnnotationItemFactory::create(const QPointF &initPositio
     auto properties = mPropertiesFactory->createFromConfig(Tools::Image);
     auto newItem = new AnnotationImage(initPosition, image, properties);
 
-    setZValue(newItem);
+	initItem(newItem);
 
     return newItem;
 }
@@ -91,7 +91,8 @@ AbstractAnnotationItem *AnnotationItemFactory::clone(const AbstractAnnotationIte
 	Q_ASSERT(item != nullptr);
 
 	auto newItem = cloneItem(item);
-	setZValue(newItem);
+
+	initItem(newItem);
 
 	return newItem;
 }
@@ -243,9 +244,10 @@ AbstractAnnotationItem *AnnotationItemFactory::cloneItem(const AbstractAnnotatio
 	return newItem;
 }
 
-void AnnotationItemFactory::setZValue(AbstractAnnotationItem *item)
+void AnnotationItemFactory::initItem(AbstractAnnotationItem *item)
 {
-	if (item != nullptr) {
+	if(item != nullptr) {
+		item->init();
 		item->setZValue(mNextZValue++);
 	}
 }
