@@ -34,7 +34,17 @@ Tools AnnotationMarkerPen::toolType() const
 
 void AnnotationMarkerPen::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
-	painter->setCompositionMode(QPainter::CompositionMode_Multiply);
 	AnnotationPen::paint(painter, option, widget);
 }
+
+QPainter::CompositionMode AnnotationMarkerPen::compositionMode() const
+{
+	return QPainter::CompositionMode_Multiply;
+}
+
+void AnnotationMarkerPen::updateShadow()
+{
+	setGraphicsEffect(nullptr);
+}
+
 } // namespace kImageAnnotator
\ No newline at end of file
