@@ -20,10 +20,6 @@
 #ifndef KIMAGEANNOTATOR_CAPSLOCKSTATUSCHECKER_H
 #define KIMAGEANNOTATOR_CAPSLOCKSTATUSCHECKER_H
 
-#if defined(_WIN32)
-#include <Windows.h>
-#endif
-
 namespace kImageAnnotator {
 
 class CapsLockStatusChecker
