@@ -35,16 +35,18 @@ namespace kImageAnnotator {
 class AnnotationItemModifier : public QObject, public QGraphicsItemGroup
 {
 Q_OBJECT
+
 public:
 	explicit AnnotationItemModifier(ZoomValueProvider *zoomValueProvider);
 	~AnnotationItemModifier() override;
 	void handleMousePress(const QPointF &pos, QList<AbstractAnnotationItem *> *items, bool isCtrlPressed);
-	void handleMouseMove(const QPointF &pos);
+	void handleMouseMove(const QPointF &pos, bool isCtrlPressed);
 	void handleMouseRelease(QList<AbstractAnnotationItem *> *items);
 	void handleMouseDoubleClick(const QPointF &pos, QList<AbstractAnnotationItem *> *items);
 	void handleSelectionAt(const QPointF &pos, QList<AbstractAnnotationItem *> *items, bool isCtrlPressed);
 	QList<AbstractAnnotationItem *> selectedItems() const;
 	QRectF boundingRect() const override;
+	void selectItem(AbstractAnnotationItem *item);
 
 public slots:
 	void clear();
