@@ -17,11 +17,13 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#include <QGuiApplication>
 #include "Config.h"
 
 namespace kImageAnnotator {
 
-Config::Config() :
+Config::Config(const QSharedPointer<ISettings> &settings) :
+	mSettings(settings),
 	mSelectTool(Tools::Pen),
 	mSmoothPathEnabled(false),
 	mSaveToolSelection(false),
@@ -241,13 +243,13 @@ void Config::setCanvasColor(const QColor &color)
 
 QByteArray Config::annotatorDockWidgetsState() const
 {
-	return mConfig.value(ConfigNameHelper::annotatorDockWidgetsState()).toByteArray();
+	return mSettings->value(ConfigNameHelper::annotatorDockWidgetsState(), QVariant()).toByteArray();
 }
 
 void Config::setAnnotatorDockWidgetsState(const QByteArray &state)
 {
-	mConfig.setValue(ConfigNameHelper::annotatorDockWidgetsState(), state);
-	mConfig.sync();
+	mSettings->setValue(ConfigNameHelper::annotatorDockWidgetsState(), state);
+	mSettings->sync();
 }
 
 bool Config::selectItemAfterDrawing() const
@@ -260,6 +262,36 @@ void Config::setSelectItemAfterDrawing(bool enabled)
 	mSelectItemAfterDrawing = enabled;
 }
 
+qreal Config::toolScaling(Tools tool) const
+{
+	return mToolToScaling[tool];
+}
+
+void Config::setToolScaling(qreal scaling, Tools tool)
+{
+	if (toolScaling(tool) == scaling) {
+		return;
+	}
+
+	mToolToScaling[tool] = scaling;
+	saveToolOpacity(tool, scaling);
+}
+
+qreal Config::toolOpacity(Tools tool) const
+{
+	return mToolToOpacity[tool];
+}
+
+void Config::setToolOpacity(qreal opacity, Tools tool)
+{
+	if (toolOpacity(tool) == opacity) {
+		return;
+	}
+
+	mToolToOpacity[tool] = opacity;
+	saveToolOpacity(tool, opacity);
+}
+
 // Private Methods
 
 void Config::initToolSettings()
@@ -270,6 +302,8 @@ void Config::initToolSettings()
 	initToolWidths();
 	initToolFillTypes();
 	initToolFonts();
+	initToolScaling();
+	initToolOpacity();
 	initObfuscateFactor();
 	initShadowEnabled();
 }
@@ -314,6 +348,20 @@ void Config::initToolFonts()
 	}
 }
 
+void Config::initToolScaling()
+{
+	for (auto toolType : mAllTools) {
+		mToolToScaling[toolType] = loadToolScaling(toolType);
+	}
+}
+
+void Config::initToolOpacity()
+{
+	for (auto toolType : mAllTools) {
+		mToolToOpacity[toolType] = loadToolOpacity(toolType);
+	}
+}
+
 void Config::initObfuscateFactor()
 {
 	for (auto toolType : mAllTools) {
@@ -342,7 +390,7 @@ void Config::initGeneralSettings()
 QColor Config::loadToolColor(Tools toolType)
 {
 	if (mSaveToolSelection) {
-		return mConfig.value(ConfigNameHelper::toolColor(toolType), defaultToolColor(toolType)).value<QColor>();
+		return mSettings->value(ConfigNameHelper::toolColor(toolType), defaultToolColor(toolType)).value<QColor>();
 	} else {
 		return defaultToolColor(toolType);
 	}
@@ -351,15 +399,15 @@ QColor Config::loadToolColor(Tools toolType)
 void Config::saveToolColor(Tools toolType, const QColor &color)
 {
 	if (mSaveToolSelection) {
-		mConfig.setValue(ConfigNameHelper::toolColor(toolType), color);
-		mConfig.sync();
+		mSettings->setValue(ConfigNameHelper::toolColor(toolType), color);
+		mSettings->sync();
 	}
 }
 
 QColor Config::loadToolTextColor(Tools toolType)
 {
 	if (mSaveToolSelection) {
-		return mConfig.value(ConfigNameHelper::toolTextColor(toolType), defaultToolTextColor(toolType)).value<QColor>();
+		return mSettings->value(ConfigNameHelper::toolTextColor(toolType), defaultToolTextColor(toolType)).value<QColor>();
 	} else {
 		return defaultToolTextColor(toolType);
 	}
@@ -368,15 +416,15 @@ QColor Config::loadToolTextColor(Tools toolType)
 void Config::saveToolTextColor(Tools toolType, const QColor &color)
 {
 	if (mSaveToolSelection) {
-		mConfig.setValue(ConfigNameHelper::toolTextColor(toolType), color);
-		mConfig.sync();
+		mSettings->setValue(ConfigNameHelper::toolTextColor(toolType), color);
+		mSettings->sync();
 	}
 }
 
 int Config::loadToolWidth(Tools toolType)
 {
 	if (mSaveToolSelection) {
-		return mConfig.value(ConfigNameHelper::toolWidth(toolType), defaultToolWidth(toolType)).value<int>();
+		return mSettings->value(ConfigNameHelper::toolWidth(toolType), defaultToolWidth(toolType)).value<int>();
 	} else {
 		return defaultToolWidth(toolType);
 	}
@@ -385,15 +433,15 @@ int Config::loadToolWidth(Tools toolType)
 void Config::saveToolWidth(Tools toolType, int size)
 {
 	if (mSaveToolSelection) {
-		mConfig.setValue(ConfigNameHelper::toolWidth(toolType), size);
-		mConfig.sync();
+		mSettings->setValue(ConfigNameHelper::toolWidth(toolType), size);
+		mSettings->sync();
 	}
 }
 
 FillModes Config::loadToolFillType(Tools toolType)
 {
 	if (mSaveToolSelection) {
-		return mConfig.value(ConfigNameHelper::toolFillType(toolType), static_cast<int>(defaultToolFillMode(toolType))).value<FillModes>();
+		return mSettings->value(ConfigNameHelper::toolFillType(toolType), static_cast<int>(defaultToolFillMode(toolType))).value<FillModes>();
 	} else {
 		return defaultToolFillMode(toolType);
 	}
@@ -402,15 +450,15 @@ FillModes Config::loadToolFillType(Tools toolType)
 void Config::saveToolFillType(Tools toolType, FillModes fillType)
 {
 	if (mSaveToolSelection) {
-		mConfig.setValue(ConfigNameHelper::toolFillType(toolType), static_cast<int>(fillType));
-		mConfig.sync();
+		mSettings->setValue(ConfigNameHelper::toolFillType(toolType), static_cast<int>(fillType));
+		mSettings->sync();
 	}
 }
 
 QFont Config::loadToolFont(Tools tool) const
 {
 	if (mSaveToolSelection) {
-		return mConfig.value(ConfigNameHelper::toolFont(tool), defaultToolFont(tool)).value<QFont>();
+		return mSettings->value(ConfigNameHelper::toolFont(tool), defaultToolFont(tool)).value<QFont>();
 	} else {
 		return defaultToolFont(tool);
 	}
@@ -419,15 +467,15 @@ QFont Config::loadToolFont(Tools tool) const
 void Config::saveToolFont(Tools tool, const QFont &font)
 {
 	if (mSaveToolSelection) {
-		mConfig.setValue(ConfigNameHelper::toolFont(tool), font);
-		mConfig.sync();
+		mSettings->setValue(ConfigNameHelper::toolFont(tool), font);
+		mSettings->sync();
 	}
 }
 
 Tools Config::loadToolType()
 {
 	if (mSaveToolSelection) {
-		return mConfig.value(ConfigNameHelper::toolType(), static_cast<int>(defaultToolType())).value<Tools>();
+		return mSettings->value(ConfigNameHelper::toolType(), static_cast<int>(defaultToolType())).value<Tools>();
 	} else {
 		return defaultToolType();
 	}
@@ -436,15 +484,15 @@ Tools Config::loadToolType()
 void Config::saveToolType(Tools toolType)
 {
 	if (mSaveToolSelection) {
-		mConfig.setValue(ConfigNameHelper::toolType(), static_cast<int>(toolType));
-		mConfig.sync();
+		mSettings->setValue(ConfigNameHelper::toolType(), static_cast<int>(toolType));
+		mSettings->sync();
 	}
 }
 
 int Config::loadToolObfuscateFactor(Tools toolType)
 {
 	if (mSaveToolSelection) {
-		return mConfig.value(ConfigNameHelper::obfuscateFactor(toolType), defaultObfuscateFactor()).value<int>();
+		return mSettings->value(ConfigNameHelper::obfuscateFactor(toolType), defaultObfuscateFactor()).value<int>();
 	} else {
 		return defaultObfuscateFactor();
 	}
@@ -453,15 +501,15 @@ int Config::loadToolObfuscateFactor(Tools toolType)
 void Config::saveToolObfuscateFactor(Tools toolType, int radius)
 {
 	if (mSaveToolSelection) {
-		mConfig.setValue(ConfigNameHelper::obfuscateFactor(toolType), radius);
-		mConfig.sync();
+		mSettings->setValue(ConfigNameHelper::obfuscateFactor(toolType), radius);
+		mSettings->sync();
 	}
 }
 
 bool Config::loadToolShadowEnabled(Tools tool)
 {
 	if (mSaveToolSelection) {
-		return mConfig.value(ConfigNameHelper::shadowEnabled(tool), defaultShadowEnabled(tool)).toBool();
+		return mSettings->value(ConfigNameHelper::shadowEnabled(tool), defaultShadowEnabled(tool)).toBool();
 	} else {
 		return defaultShadowEnabled(tool);
 	}
@@ -470,8 +518,42 @@ bool Config::loadToolShadowEnabled(Tools tool)
 void Config::saveToolShadowEnabled(Tools tool, bool enabled)
 {
 	if (mSaveToolSelection) {
-		mConfig.setValue(ConfigNameHelper::shadowEnabled(tool), enabled);
-		mConfig.sync();
+		mSettings->setValue(ConfigNameHelper::shadowEnabled(tool), enabled);
+		mSettings->sync();
+	}
+}
+
+qreal Config::loadToolScaling(Tools tool)
+{
+	if (mSaveToolSelection) {
+		return mSettings->value(ConfigNameHelper::toolScaling(tool), defaultToolScaling()).value<qreal>();
+	} else {
+		return defaultToolOpacity();
+	}
+}
+
+void Config::saveToolScaling(Tools tool, qreal scaling)
+{
+	if (mSaveToolSelection) {
+		mSettings->setValue(ConfigNameHelper::toolScaling(tool), scaling);
+		mSettings->sync();
+	}
+}
+
+qreal Config::loadToolOpacity(Tools tool)
+{
+	if (mSaveToolSelection) {
+		return mSettings->value(ConfigNameHelper::toolOpacity(tool), defaultToolOpacity()).value<qreal>();
+	} else {
+		return defaultToolOpacity();
+	}
+}
+
+void Config::saveToolOpacity(Tools tool, qreal opacity)
+{
+	if (mSaveToolSelection) {
+		mSettings->setValue(ConfigNameHelper::toolOpacity(tool), opacity);
+		mSettings->sync();
 	}
 }
 
@@ -563,8 +645,8 @@ FillModes Config::defaultToolFillMode(Tools toolType)
 
 QFont Config::defaultToolFont(Tools tool)
 {
-	auto textFont = QFont(QLatin1String("Times"), 15, QFont::Bold);
-	auto numberFont = QFont(QLatin1String("Helvetica"), 20, QFont::Bold);
+	auto textFont = QFont(QGuiApplication::font().family(), 15, QFont::Bold);
+    auto numberFont = QFont(QGuiApplication::font().family(), 20, QFont::Bold);
 
 	switch (tool) {
 		case Tools::Number:
@@ -602,8 +684,8 @@ bool Config::defaultShadowEnabled(Tools tool)
 		case Tools::Rect:
 		case Tools::Ellipse:
 		case Tools::Sticker:
-			return true;
 		case Tools::Text:
+			return true;
 		case Tools::TextPointer:
 		case Tools::TextArrow:
 		case Tools::Blur:
@@ -619,4 +701,14 @@ bool Config::defaultShadowEnabled(Tools tool)
 	}
 }
 
+qreal Config::defaultToolScaling()
+{
+	return 1.0;
+}
+
+qreal Config::defaultToolOpacity()
+{
+	return 1.0;
+}
+
 } // namespace kImageAnnotator
