@@ -25,8 +25,8 @@
 #include <QColor>
 #include <QHash>
 #include <QFont>
-#include <QSettings>
 
+#include "ISettings.h"
 #include "src/common/enum/Tools.h"
 #include "src/common/enum/FillModes.h"
 #include "src/common/enum/NumberUpdateMode.h"
@@ -38,7 +38,7 @@ class Config : public QObject
 {
 Q_OBJECT
 public:
-	explicit Config();
+	explicit Config(const QSharedPointer<ISettings> &settings);
 	~Config() override = default;
 
 public slots:
@@ -89,11 +89,17 @@ public slots:
 	bool selectItemAfterDrawing() const;
 	void setSelectItemAfterDrawing(bool enabled);
 
+	qreal toolScaling(Tools tool) const;
+	void setToolScaling(qreal scaling, Tools tool);
+
+	qreal toolOpacity(Tools tool) const;
+	void setToolOpacity(qreal opacity, Tools tool);
+
 signals:
 	void numberUpdateModeChanged(enum NumberUpdateMode numberUpdateMode) const;
 
 private:
-	QSettings mConfig;
+	QSharedPointer<ISettings> mSettings;
 	QList<Tools> mAllTools;
 	Tools mSelectTool;
 	QHash<Tools, QColor> mToolToColor;
@@ -103,6 +109,8 @@ private:
 	QHash<Tools, QFont> mToolToFont;
 	QHash<Tools, int> mToolToObfuscationFactor;
 	QHash<Tools, bool> mToolToShadowEnabled;
+	QHash<Tools, qreal> mToolToOpacity;
+	QHash<Tools, qreal> mToolToScaling;
 	bool mSmoothPathEnabled;
 	bool mSaveToolSelection;
 	int mSmoothFactor;
@@ -118,6 +126,8 @@ private:
 	void initToolWidths();
 	void initToolFillTypes();
 	void initToolFonts();
+	void initToolScaling();
+	void initToolOpacity();
 	void initObfuscateFactor();
 	void initShadowEnabled();
 	void initGeneralSettings();
@@ -138,6 +148,10 @@ private:
 	void saveToolObfuscateFactor(Tools toolType, int radius);
 	bool loadToolShadowEnabled(Tools tool);
 	void saveToolShadowEnabled(Tools tool, bool enabled);
+	qreal loadToolScaling(Tools tool);
+	void saveToolScaling(Tools tool, qreal scaling);
+	qreal loadToolOpacity(Tools tool);
+	void saveToolOpacity(Tools tool, qreal opacity);
 
 	static QColor defaultToolColor(Tools toolType);
 	static QColor defaultToolTextColor(Tools toolType);
@@ -147,6 +161,8 @@ private:
 	static Tools defaultToolType();
 	static int defaultObfuscateFactor();
 	static bool defaultShadowEnabled(Tools tool);
+	static qreal defaultToolScaling();
+	static qreal defaultToolOpacity();
 };
 
 } // namespace kImageAnnotator
