@@ -39,6 +39,8 @@ public:
 	static QString obfuscateFactor(Tools tool);
 	static QString shadowEnabled(Tools tool);
 	static QString annotatorDockWidgetsState();
+	static QString toolOpacity(Tools tool);
+	static QString toolScaling(Tools tool);
 };
 
 }
