@@ -21,20 +21,26 @@
 
 namespace kImageAnnotator {
 
-QIcon IconLoader::load(QString name)
+QIcon IconLoader::load(const QString &name)
 {
 	auto type = getThemePrefix();
-	return QIcon(QStringLiteral(":/icons/") + type + name);
+	return QIcon(QLatin1String(":/icons/") + type + name);
+}
+
+QPixmap IconLoader::loadAsPixmap(const QString &name)
+{
+	auto type = getThemePrefix();
+	return QPixmap(QLatin1String(":/icons/") + type + name);
 }
 
 QString IconLoader::getThemePrefix()
 {
-	return isDarkTheme() ? QStringLiteral("dark/") : QStringLiteral("light/");
+	return isDarkTheme() ? QLatin1String("dark/") : QLatin1String("light/");
 }
 
 double IconLoader::getThemeLuma()
 {
-	auto color = QApplication::palette().background().color();
+	auto color = QApplication::palette().window().color();
 	return 0.2126 * color.redF() + 0.7152 * color.greenF() + 0.0722 * color.blueF();
 }
 
