@@ -29,7 +29,8 @@ namespace kImageAnnotator {
 class IconLoader
 {
 public:
-	static QIcon load(QString name);
+	static QIcon load(const QString &name);
+	static QPixmap loadAsPixmap(const QString &name);
 
 private:
 	IconLoader() = default;
