@@ -27,6 +27,7 @@
 #include "src/gui/cropper/CropWidget.h"
 #include "src/gui/scaler/ScaleWidget.h"
 #include "src/gui/rotator/RotateWidget.h"
+#include "src/gui/cutter/CutWidget.h"
 #include "src/gui/canvasModifier/ModifyCanvasWidget.h"
 
 namespace kImageAnnotator {
@@ -61,7 +62,9 @@ public slots:
 	void showCropper();
 	void showScaler();
 	void showRotator();
+	void showCutter();
 	void showCanvasModifier();
+	void setControlsWidgetVisible(bool enabled);
 	void setSettingsCollapsed(bool isCollapsed);
 	void setTabBarAutoHide(bool enabled);
 	void setStickers(const QStringList &stickerPaths, bool keepDefault);
@@ -73,6 +76,7 @@ private:
 	CropWidget *mCropWidget;
 	ScaleWidget *mScaleWidget;
 	RotateWidget *mRotateWidget;
+	CutWidget *mCutWidget;
 	ModifyCanvasWidget *mModifyCanvasWidget;
 };
 
