@@ -24,6 +24,7 @@
 #include <kImageAnnotator/KImageAnnotator.h>
 
 #include "CoreView.h"
+#include "src/backend/SettingsAdapter.h"
 
 inline void initResource()
 {
@@ -226,6 +227,12 @@ void KImageAnnotator::showCanvasModifier()
 	d->mCoreView.showCanvasModifier();
 }
 
+void KImageAnnotator::showCutter()
+{
+	Q_D(KImageAnnotator);
+	d->mCoreView.showCutter();
+}
+
 void KImageAnnotator::setSettingsCollapsed(bool isCollapsed)
 {
 	Q_D(KImageAnnotator);
@@ -256,9 +263,18 @@ void KImageAnnotator::setSelectItemAfterDrawing(bool enabled)
 	d->mConfig.setSelectItemAfterDrawing(enabled);
 }
 
+void KImageAnnotator::setControlsWidgetVisible(bool enabled)
+{
+	Q_D(KImageAnnotator);
+	d->mCoreView.setControlsWidgetVisible(enabled);
+}
+
 // KImageAnnotatorPrivate
 
-KImageAnnotatorPrivate::KImageAnnotatorPrivate(KImageAnnotator *kImageAnnotator) : q_ptr(kImageAnnotator), mCoreView(&mConfig)
+KImageAnnotatorPrivate::KImageAnnotatorPrivate(KImageAnnotator *kImageAnnotator) :
+	q_ptr(kImageAnnotator),
+	mConfig(QSharedPointer<ISettings>(new SettingsAdapter)),
+	mCoreView(&mConfig)
 {
 	initResource();
 
