@@ -27,6 +27,8 @@
 #include "AnnotationTabContextMenu.h"
 #include "AnnotationTabCloser.h"
 #include "AnnotationTabClickEventFilter.h"
+#include "src/common/filter/KeyEventFilter.h"
+
 
 namespace kImageAnnotator {
 
@@ -37,6 +39,7 @@ public:
 	AnnotationTabWidget(Config *config, AbstractSettingsProvider *settingsProvider);
 	~AnnotationTabWidget() override = default;
 	int addTab(const QPixmap &image, const QString &title, const QString &toolTip);
+	int insertTab(int index, const QPixmap &image, const QString &title, const QString &toolTip);
 	AnnotationArea* currentAnnotationArea() const;
 	AnnotationArea *annotationAreaAt(int index) const;
 	ZoomValueProvider* currentZoomValueProvider() const;
@@ -68,6 +71,8 @@ private:
 	AnnotationTabContextMenu *mTabContextMenu;
 	AnnotationTabCloser *mTabCloser;
 	AnnotationTabClickEventFilter *mTabClickFilter;
+	AnnotationItemClipboard *mItemClipboard;
+	KeyEventFilter mKeyEventFilter;
 
 private slots:
 	void updateCurrentWidget(int index);
