@@ -109,6 +109,16 @@ ImageEffects MockSettingsProvider::effect() const
 	return ImageEffects::NoEffect;
 }
 
+qreal MockSettingsProvider::scaling() const
+{
+	return 1.0;
+}
+
+qreal MockSettingsProvider::opacity() const
+{
+	return 1.0;
+}
+
 bool MockSettingsProvider::shadowEnabled() const
 {
 	return mShadowEnabled;
