@@ -23,7 +23,7 @@ void StickerPickerTest::TestSelectSticker_Should_EmitSignal_When_StickerChanged(
 {
 	StickerPicker stickerPicker(nullptr);
 	QSignalSpy spy(&stickerPicker, &StickerPicker::stickerSelected);
-	auto expectedStickerPath = QLatin1Literal(":/stickers/nerd_face.svg");
+	auto expectedStickerPath = QStringLiteral(":/stickers/nerd_face.svg");
 
 	stickerPicker.setSticker(expectedStickerPath);
 
@@ -32,4 +32,4 @@ void StickerPickerTest::TestSelectSticker_Should_EmitSignal_When_StickerChanged(
 	QCOMPARE(resultSize, expectedStickerPath);
 }
 
-TEST_MAIN(StickerPickerTest);
\ No newline at end of file
+TEST_MAIN(StickerPickerTest);
