@@ -44,6 +44,13 @@
         <translation>Izbriši</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::AnnotationControlsWidget</name>
+    <message>
+        <source>Controls</source>
+        <translation>Kontrole</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::AnnotationGeneralSettings</name>
     <message>
@@ -88,6 +95,14 @@
         <source>Item Settings</source>
         <translation>Postavke elementa</translation>
     </message>
+    <message>
+        <source>Scale</source>
+        <translation>Omjer</translation>
+    </message>
+    <message>
+        <source>Opacity</source>
+        <translation>Neprozirnost</translation>
+    </message>
 </context>
 <context>
     <name>kImageAnnotator::AnnotationTabContextMenu</name>
@@ -130,6 +145,37 @@
         <translation>Deaktivirano</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::Controls</name>
+    <message>
+        <source>Undo</source>
+        <translation>Poništi</translation>
+    </message>
+    <message>
+        <source>Redo</source>
+        <translation>Ponovi</translation>
+    </message>
+    <message>
+        <source>Crop</source>
+        <translation>Izreži</translation>
+    </message>
+    <message>
+        <source>Scale</source>
+        <translation>Omjer</translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation>Okreni</translation>
+    </message>
+    <message>
+        <source>Modify canvas</source>
+        <translation>Promijeni platno</translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation>Izreži</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::CropWidget</name>
     <message>
@@ -157,6 +203,25 @@
         <translation>Primijeni</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::CutWidget</name>
+    <message>
+        <source>Vertical</source>
+        <translation>Okomito</translation>
+    </message>
+    <message>
+        <source>Horizontal</source>
+        <translation>Vodoravno</translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation>Primijeni</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Odustani</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::FillModePicker</name>
     <message>
@@ -459,5 +524,17 @@ Okretanje množiteljima koji nisu 90° može smanjiti kvalitetu slike.</translat
         <source>Reset Zoom (%1)</source>
         <translation>Poništi zumiranje (%1)</translation>
     </message>
+    <message>
+        <source>Reset Zoom</source>
+        <translation>Resetiraj zumiranje</translation>
+    </message>
+    <message>
+        <source>Fit Image</source>
+        <translation>Prilagodi sliku</translation>
+    </message>
+    <message>
+        <source>Fit image to view (%1)</source>
+        <translation>Prilagodi sliku za prikaz (%1)</translation>
+    </message>
 </context>
 </TS>
