@@ -44,6 +44,13 @@
         <translation>Elimina</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::AnnotationControlsWidget</name>
+    <message>
+        <source>Controls</source>
+        <translation>Controlli</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::AnnotationGeneralSettings</name>
     <message>
@@ -88,6 +95,14 @@
         <source>Item Settings</source>
         <translation>Impostazione elemento</translation>
     </message>
+    <message>
+        <source>Scale</source>
+        <translation>Scala</translation>
+    </message>
+    <message>
+        <source>Opacity</source>
+        <translation>Opacità</translation>
+    </message>
 </context>
 <context>
     <name>kImageAnnotator::AnnotationTabContextMenu</name>
@@ -130,6 +145,37 @@
         <translation>Disabilitato</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::Controls</name>
+    <message>
+        <source>Undo</source>
+        <translation>Annulla</translation>
+    </message>
+    <message>
+        <source>Redo</source>
+        <translation>Rifare</translation>
+    </message>
+    <message>
+        <source>Crop</source>
+        <translation>Ritaglia</translation>
+    </message>
+    <message>
+        <source>Scale</source>
+        <translation>Scala</translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation>Ruota</translation>
+    </message>
+    <message>
+        <source>Modify canvas</source>
+        <translation>Modifica tela</translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation>Taglia</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::CropWidget</name>
     <message>
@@ -157,6 +203,25 @@
         <translation>Applica</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::CutWidget</name>
+    <message>
+        <source>Vertical</source>
+        <translation>Verticale</translation>
+    </message>
+    <message>
+        <source>Horizontal</source>
+        <translation>Orizzontale</translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation>Applica</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annulla</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::FillModePicker</name>
     <message>
@@ -459,5 +524,17 @@ La rotazione di moltiplicatori diversi da 90° potrebbe introdurre una perdita d
         <source>Reset Zoom (%1)</source>
         <translation>Reimposta zoom (%1)</translation>
     </message>
+    <message>
+        <source>Reset Zoom</source>
+        <translation>Ripristina zoom</translation>
+    </message>
+    <message>
+        <source>Fit Image</source>
+        <translation>Adatta immagine</translation>
+    </message>
+    <message>
+        <source>Fit image to view (%1)</source>
+        <translation>Adatta immagine alla visualizzazione (%1)</translation>
+    </message>
 </context>
 </TS>
