@@ -44,6 +44,13 @@
         <translation>Usuń</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::AnnotationControlsWidget</name>
+    <message>
+        <source>Controls</source>
+        <translation>Sterowanie</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::AnnotationGeneralSettings</name>
     <message>
@@ -88,6 +95,14 @@
         <source>Item Settings</source>
         <translation>Ustawienia elementów</translation>
     </message>
+    <message>
+        <source>Scale</source>
+        <translation>Skala</translation>
+    </message>
+    <message>
+        <source>Opacity</source>
+        <translation>Nieprzezroczystość</translation>
+    </message>
 </context>
 <context>
     <name>kImageAnnotator::AnnotationTabContextMenu</name>
@@ -130,6 +145,37 @@
         <translation>Wyłączone</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::Controls</name>
+    <message>
+        <source>Undo</source>
+        <translation>Cofnij</translation>
+    </message>
+    <message>
+        <source>Redo</source>
+        <translation>Powtórz</translation>
+    </message>
+    <message>
+        <source>Crop</source>
+        <translation>Przytnij</translation>
+    </message>
+    <message>
+        <source>Scale</source>
+        <translation>Skala</translation>
+    </message>
+    <message>
+        <source>Rotate</source>
+        <translation>Obróć</translation>
+    </message>
+    <message>
+        <source>Modify canvas</source>
+        <translation>Modyfikuj kanwę</translation>
+    </message>
+    <message>
+        <source>Cut</source>
+        <translation>Wytnij</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::CropWidget</name>
     <message>
@@ -157,6 +203,25 @@
         <translation>Zastosuj</translation>
     </message>
 </context>
+<context>
+    <name>kImageAnnotator::CutWidget</name>
+    <message>
+        <source>Vertical</source>
+        <translation>Pionowo</translation>
+    </message>
+    <message>
+        <source>Horizontal</source>
+        <translation>Poziomo</translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation>Zastosuj</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Anuluj</translation>
+    </message>
+</context>
 <context>
     <name>kImageAnnotator::FillModePicker</name>
     <message>
@@ -459,5 +524,17 @@ Obracanie przez mnożniki inne niż 90° może spowodować utratę jakości.</tr
         <source>Reset Zoom (%1)</source>
         <translation>Resetuj powiększenie (%1)</translation>
     </message>
+    <message>
+        <source>Reset Zoom</source>
+        <translation>Zresetuj powiększenie</translation>
+    </message>
+    <message>
+        <source>Fit Image</source>
+        <translation>Dopasuj obraz</translation>
+    </message>
+    <message>
+        <source>Fit image to view (%1)</source>
+        <translation>Dopasuj obraz do widoku (%1)</translation>
+    </message>
 </context>
 </TS>
